# GNNE

GNNE: Abbreviation of Graph Neural Network Embeddings. This repo mainly implements the mainstream Graph Embedding algorithm, which can quickly and efficiently help researchers conduct model experiments.